@@ -1,3 +1,3 @@
-from . import dynamic, user, video
+from . import dynamic, user, video,bangumi
 from .src.utils import Verify, nyanpass
 from .src import exception
